---
title: <span class="badge object-type-scalar"></span> DurationInDaysHoursMinutesSeconds
---
# <span class="badge object-type-scalar"></span> DurationInDaysHoursMinutesSeconds

Time: duration (d hh:mm:ss)

## Definition

```python
# Time: duration (d hh:mm:ss)
DurationInDaysHoursMinutesSeconds: typing.Literal["dtdhms"] = "dtdhms"
```
